@@ -11,8 +11,8 @@ sub request {
     my ( $self, $request ) = @_;
     my $path = sprintf '%s/http_response/%s/%s.%s', dirname(__FILE__), $request->uri->host, $request->uri->path, $request->method;
     my %query_form = $request->uri->query_form;
-    while ( my ( $k, $v ) = each %query_form ) {
-        $path .= sprintf '.%s-%s', $k, $v;
+    foreach my $k ( sort keys %query_form ) {
+        $path .= sprintf '.%s-%s', $k, $query_form{$k};
     }
     my $response = HTTP::Response->new;
     if ( -f $path ) {
